summaryrefslogtreecommitdiffstats
path: root/src/modules/objects/class_groupbox.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/modules/objects/class_groupbox.cpp')
-rw-r--r--src/modules/objects/class_groupbox.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/modules/objects/class_groupbox.cpp b/src/modules/objects/class_groupbox.cpp
index 07f73bea..d0ecae08 100644
--- a/src/modules/objects/class_groupbox.cpp
+++ b/src/modules/objects/class_groupbox.cpp
@@ -29,7 +29,7 @@
#include "kvi_locale.h"
#include "kvi_iconmanager.h"
// Tables used in $tqsetAlignment , $tqalignment and in $setOrientation & $orientation
const char * const align_tbl[] = {
"Left",
@@ -91,7 +91,7 @@ const int align_cod[] = {
Adds an empty cell at the next free position.
!fn: <string> $tqalignment()
Returns the tqalignment of the group box title.
- !fn: $tqsetAlignment(<tqalignment:string>)
+ !fn: $setAlignment(<tqalignment:string>)
Set the tqalignment of the groupbox; Valid values are Left,Right,HCenter.
!fn: $setOrientation<orientation:string>
Sets the group box's orientation. Valid values are:Qt::Horizontal,Qt::Vertical.
@@ -108,7 +108,7 @@ const int align_cod[] = {
#then the groupbox [br]
%gb=$new(groupbox,%widget)[br]
%gb->$setTitle(Login)[br]
- %gb->$tqsetAlignment("Left")[br]
+ %gb->$setAlignment("Left")[br]
[br]
#now we create the labels and lineedits.[br]
%labeluser=$new(label,%gb)[br]
@@ -166,7 +166,7 @@ KVSO_BEGIN_REGISTERCLASS(KviKvsObject_groupbox,"groupbox","widget")
KVSO_REGISTER_HANDLER(KviKvsObject_groupbox,"columns", functionColumns)
KVSO_REGISTER_HANDLER(KviKvsObject_groupbox,"addSpace", functionAddSpace)
KVSO_REGISTER_HANDLER(KviKvsObject_groupbox,"tqalignment", functionAlignment)
- KVSO_REGISTER_HANDLER(KviKvsObject_groupbox,"tqsetAlignment", functionSetAlignment)
+ KVSO_REGISTER_HANDLER(KviKvsObject_groupbox,"setAlignment", functionSetAlignment)
KVSO_REGISTER_HANDLER(KviKvsObject_groupbox,"setOrientation", functionSetOrientation)
KVSO_REGISTER_HANDLER(KviKvsObject_groupbox,"isChecked", functionIsChecked)
KVSO_REGISTER_HANDLER(KviKvsObject_groupbox,"setChecked", functionSetChecked)
@@ -317,7 +317,7 @@ bool KviKvsObject_groupbox::functionSetAlignment(KviKvsObjectFunctionCall *c)
{
if(KviTQString::equalCI(szAlign, align_tbl[i]))
{
- ((KviTalGroupBox *)widget())->tqsetAlignment(align_cod[i]);
+ ((KviTalGroupBox *)widget())->setAlignment(align_cod[i]);
return true;
}
}
@@ -29,7 +29,7 @@
#include "kvi_locale.h"
#include "kvi_iconmanager.h"
-// Tables used in $tqsetAlignment , $tqalignment and in $setOrientation & $orientation
+// Tables used in $setAlignment , $tqalignment and in $setOrientation & $orientation
const char * const align_tbl[] = {
"Left",